<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:template match="CONTROL[@TYPE='LABEL']" mode="TITLE-LEFT">
		<xsl:param name="titleStyle"></xsl:param>
		<xsl:param name="controlStyle"></xsl:param>
		<tr>
            <xsl:choose>
               <xsl:when test="position() mod 2">
                  <xsl:attribute name="class">sb-formview-alternaterow</xsl:attribute>
               </xsl:when>
               <xsl:otherwise>
                  <xsl:attribute name="class">sb-formview-row</xsl:attribute>
               </xsl:otherwise>
            </xsl:choose>
			<td width="50%">
				<xsl:attribute name="class"><xsl:value-of select="$titleStyle"/></xsl:attribute>				
				<xsl:value-of select="@TITLE"/> 
			</td>
			<td>
				<div>
					<xsl:attribute name="class"><xsl:value-of select="$controlStyle"/></xsl:attribute>
					<xsl:choose>
						<xsl:when test="@VALUE='--On--'">
							<img width="15" height="15" src="{$skinPath}/icons/checked.png" alt=""/>
						</xsl:when>
						<xsl:when test="@VALUE='--Off--'">
							<img width="15" height="15" src="{$skinPath}/icons/unchecked.png" alt=""/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="@VALUE"/> 
						</xsl:otherwise>
					</xsl:choose>
				</div>
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="CONTROL[@TYPE='BUTTON']" name="BUTTON-CONTROL">
		<xsl:param name="style"/>
		<xsl:param name="class"/>
		<xsl:param name="title"/>
		<xsl:param name="icon" select="@ICON"/>
		<xsl:param name="action" select="@ACTION"/>
		<xsl:param name="id" value="@NAME"/>
		<table cellpadding="0" cellspacing="0" border="0">
			<xsl:attribute name="style">cursor: pointer;<xsl:value-of select="$style"/></xsl:attribute>
			<xsl:attribute name="class"><xsl:value-of select="$class"/></xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="$id"/></xsl:attribute>
			<xsl:attribute name="onclick">
				<xsl:value-of select="$action"/>
			</xsl:attribute>
			<tr>
				<td align="right" style="padding:0px;">
					<img src="{$skinPath}/images/button_left.gif" style="border-width:0px;" alt=""/>
				</td>
				<xsl:if test="$icon!=''">
					<td style="background-image:url({$skinPath}/images/button_middle.gif);padding-left:5px;padding-right:5px;">
						<img src="{$skinPath}/icons/{$icon}" />
					</td>
				</xsl:if>
				<td class="" style="white-space: nowrap; width: 100%; text-align: center; background-image: url({$skinPath}/images/button_middle.gif); padding: 0px; padding-right: 4px;padding-left: 4px;">
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="$action=''">sb-login-control-button-disabled</xsl:when>
							<xsl:otherwise><xsl:value-of select="$class"/></xsl:otherwise>
						</xsl:choose> 
					</xsl:attribute>
					<xsl:choose>
						<xsl:when test="$title"><xsl:value-of select="$title"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="@TITLE"/></xsl:otherwise>
					</xsl:choose>
				</td>
				<td align="left" style="padding: 0px;">
					<img src="{$skinPath}/images/button_right.gif" style="border-width:0px;" alt=""/>
				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template match="CONTROL[@TYPE='BUTTON']" name="LARGE-BUTTON-CONTROL" mode="LARGE">
		<xsl:param name="style"/>
		<xsl:param name="class"/>
		<xsl:param name="title" select="@TITLE"/>
		<xsl:param name="icon" select="@ICON"/>
		<xsl:param name="leftImage">images/large_button_left.gif</xsl:param>
		<xsl:param name="middleImage">images/large_button_middle.gif</xsl:param>
		<xsl:param name="rightImage">images/large_button_right.gif</xsl:param>
		<xsl:param name="action" select="@ACTION"/>

		<table cellpadding="0" cellspacing="0" border="0">
			<xsl:attribute name="style">cursor: pointer;<xsl:value-of select="$style"/></xsl:attribute>
			<xsl:if test="$class!=''">
				<xsl:attribute name="class"><xsl:value-of select="$class"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="$action!=''">
				<xsl:attribute name="onclick">
					<xsl:value-of select="$action"/>
				</xsl:attribute>
			</xsl:if>
			<tr>
				<td><img src="{$skinPath}/{$leftImage}" border="0" alt=""/></td>
				<td class="sb-large-button-text" style="white-space: nowrap; background-image: url('{$skinPath}/{$middleImage}');">
					<xsl:if test="$icon!=''">
						<img src="{$skinPath}/{$icon}" border="0" alt="" style="margin-right: 5px; vertical-align: middle;"/>
					</xsl:if>
					<xsl:value-of select="$title"/>
				</td>
				<td><img src="{$skinPath}/{$rightImage}" border="0" alt=""/></td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template match="CONTROL[@TYPE='BUTTON']" mode="TITLE-LEFT">
		<xsl:param name="titleClass"></xsl:param>
		<xsl:param name="controlClass"></xsl:param>
		<xsl:param name="titleStyle"></xsl:param>
		<xsl:param name="controlStyle"></xsl:param>
		<xsl:param name="controlEnvStyle"></xsl:param>
		<xsl:param name="rowClass"></xsl:param>
		<xsl:param name="onClick"></xsl:param>
		<xsl:param name="inOneRow"></xsl:param>
		<table width="100%" cellpadding="0" cellspacing="0" border="0" style="width: 100%;">
			<tr>
				<xsl:attribute name="class"><xsl:value-of select="$rowClass"/></xsl:attribute>
				<td>
					<xsl:call-template name="CONTROL-WIDTH">
						<xsl:with-param name="inOneRow" select="$inOneRow"/>
						<xsl:with-param name="titleStyle" select="$titleStyle"/>
					</xsl:call-template>
					<xsl:if test="$titleClass != ''">
						<xsl:attribute name="class"><xsl:value-of select="$titleClass"/></xsl:attribute>
					</xsl:if>
					<xsl:value-of select="@TITLE"/> 
				</td>
				<td>
					<xsl:call-template name="CONTROL-ENV-WIDTH">
						<xsl:with-param name="inOneRow" select="$inOneRow"/>
						<xsl:with-param name="controlEnvStyle" select="$controlEnvStyle"/>
					</xsl:call-template>
					<xsl:call-template name="BUTTON-CONTROL">
						<xsl:with-param name="class"><xsl:value-of select="$controlClass"/></xsl:with-param>
						<xsl:with-param name="style"><xsl:value-of select="$controlStyle"/></xsl:with-param>
						<xsl:with-param name="title"><xsl:value-of select="@CAPTION"/></xsl:with-param>
						<xsl:with-param name="action"><xsl:value-of select="$onClick"/></xsl:with-param>
					</xsl:call-template>
					<xsl:if test="$inOneRow = '' and @DESCRIPTION">
						<div class="sb-text-pale"><xsl:value-of select="@DESCRIPTION"/></div>
					</xsl:if>
				</td>
				<xsl:if test="$inOneRow and @DESCRIPTION">
					<td style="width: 40%;">
						<div class="sb-text-pale"><xsl:value-of select="@DESCRIPTION"/></div>
					</td>
				</xsl:if>
			</tr>
		</table>
	</xsl:template>

	<xsl:template name="OK-CANCEL-BUTTONS">
		<xsl:param name="okAction"/>
		<xsl:param name="cancelAction"/>
		<xsl:param name="isRequiredFieldsExists"/>
		<table cellpadding="0" cellspacing="0" width="100%">
		<tr>
		<xsl:if test="$isRequiredFieldsExists != ''">
			<td align="left" style="white-space: nowrap;"><xsl:call-template name="REQUIRED-FIELDS"/></td>
		</xsl:if>
		<td style="width: 100%;" align="right">
			<table cellpadding="3">
			<tr>
				<td align="center">
					<xsl:if test="/SITEBUILDER-PAGE/JS-LOCALE/CONTEXT-HELP-BUTTON-OK">
						<xsl:attribute name="onmouseout">SetContextHelp();</xsl:attribute>
						<xsl:attribute name="onmouseover">SetContextHelp('CONTEXT-HELP-BUTTON-OK');</xsl:attribute>
					</xsl:if>
					<xsl:call-template name="OK-BUTTON">
						<xsl:with-param name="action"><xsl:value-of select="$okAction"/></xsl:with-param>
					</xsl:call-template>
				</td>
				<td align="center">
					<xsl:if test="/SITEBUILDER-PAGE/JS-LOCALE/CONTEXT-HELP-BUTTON-CANCEL">
						<xsl:attribute name="onmouseout">SetContextHelp();</xsl:attribute>
						<xsl:attribute name="onmouseover">SetContextHelp('CONTEXT-HELP-BUTTON-CANCEL');</xsl:attribute>
					</xsl:if>
					<xsl:call-template name="CANCEL-BUTTON">
						<xsl:with-param name="action"><xsl:value-of select="$cancelAction"/></xsl:with-param>
					</xsl:call-template>
				</td>
			</tr>
			</table>
		</td>
		</tr>
		</table>
	</xsl:template>

	<xsl:template name="OK-BUTTON">
	<xsl:param name="action"/>
<!--	<table onclick="{$action}" style="cursor: pointer; width: 70px;" border="0" cellpadding="0" cellspacing="0"> -->
	<table cellspacing="0" cellpadding="0" border="0" style="cursor: pointer; width: 90px;" onclick="{$action}">
		<tr>
			<td style="width: 1px;"><img src="{$skinPath}/images/button_ok_left.gif"/></td>
			<td style="background-image: url({$skinPath}/images/button_ok_middle.gif); background-repeat:repeat-x; width: 1px; padding-left: 5px;"><img src="{$skinPath}/icons/ok.gif"/></td>
			<td style="background-image: url({$skinPath}/images/button_ok_middle.gif);" align="center" class="sb-button-ok"><xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/OK-TITLE"/></td>
			<td style="width: 1px;"><img src="{$skinPath}/images/button_ok_right.gif"/></td>
		</tr>
	</table>
	</xsl:template>
	
	<xsl:template name="CANCEL-BUTTON">
	<xsl:param name="action"/>
	<table onclick="{$action}" style="cursor: pointer; width: 90px;" border="0" cellpadding="0" cellspacing="0">
		<tr>
			<td style="width: 1px;">
				<img src="{$skinPath}/images/button_left.gif"/>
			</td>
			<td style="background-image: url({$skinPath}/images/button_middle.gif); background-repeat:repeat-x; width: 1px; padding-left: 5px;">
				<img src="{$skinPath}/icons/cancel.gif"/>
			</td>
			<td style="background-image: url({$skinPath}/images/button_middle.gif);" align="center" class="sb-button-cancel">
				<xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/CANCEL-TITLE"/>
			</td>
			<td style="width: 1px;"><img src="{$skinPath}/images/button_right.gif"/></td>
		</tr>
	</table>
	</xsl:template>

	<xsl:template name="BUTTON">
		<xsl:param name="action"/>
		<xsl:param name="title"/>
		<xsl:param name="id"/>
		<xsl:param name="align" select="'center'"/>
		<table align="{$align}" onclick="{$action} return false;" style="cursor:pointer; width:70px;" border="0" cellpadding="0" cellspacing="0">
			<xsl:if test="$id">
				<xsl:attribute name="id"><xsl:value-of select="$id"/></xsl:attribute>
			</xsl:if>
			<tr>
				<td><img src="{$skinPath}/images/button_left.gif"/></td>
				<td class="sb-text" style="width:100%; background-image: url({$skinPath}/images/button_middle.gif); white-space: nowrap;" align="center"><xsl:value-of select="$title"/></td>
				<td><img src="{$skinPath}/images/button_right.gif"/></td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template name="CONTROL-WIDTH">
		<xsl:param name="inOneRow"></xsl:param>
		<xsl:param name="titleStyle"></xsl:param>
		<xsl:attribute name="style">
			<xsl:choose>
				<xsl:when test="$inOneRow and @DESCRIPTION">width: 30%;</xsl:when>
				<xsl:otherwise>width: 50%;</xsl:otherwise>
			</xsl:choose>
			<xsl:value-of select="$titleStyle"/>
		</xsl:attribute>
	</xsl:template>

	<xsl:template name="CONTROL-ENV-WIDTH">
		<xsl:param name="inOneRow"></xsl:param>
		<xsl:param name="controlEnvStyle"></xsl:param>
		<xsl:attribute name="style">
			<xsl:choose>
				<xsl:when test="$inOneRow and @DESCRIPTION">width: 30%;</xsl:when>
				<xsl:otherwise>width: 50%;</xsl:otherwise>
			</xsl:choose>
			<xsl:value-of select="$controlEnvStyle"/>
		</xsl:attribute>
	</xsl:template>

	<xsl:template match="CONTROL[@TYPE='COMBO-BOX']" mode="TITLE-LEFT">
		<xsl:param name="titleClass"></xsl:param>
		<xsl:param name="controlClass"></xsl:param>
		<xsl:param name="descriptionClass">sb-text-pale</xsl:param>
		<xsl:param name="titleStyle"></xsl:param>
		<xsl:param name="controlStyle"></xsl:param>
		<xsl:param name="controlEnvStyle"></xsl:param>
		<xsl:param name="rowClass"></xsl:param>
		<xsl:param name="onChange"></xsl:param>
		<xsl:param name="inOneRow"></xsl:param>
		<table width="100%" cellpadding="0" cellspacing="0" border="0" style="width: 100%;">
			<tr style="vertical-align: baseline;">
				<xsl:attribute name="class"><xsl:value-of select="$rowClass"/></xsl:attribute>
				<td>
					<xsl:call-template name="CONTROL-WIDTH">
						<xsl:with-param name="inOneRow" select="$inOneRow"/>
						<xsl:with-param name="titleStyle" select="$titleStyle"/>
					</xsl:call-template>
					<xsl:if test="$titleClass != ''">
						<xsl:attribute name="class"><xsl:value-of select="$titleClass"/></xsl:attribute>
					</xsl:if>
					<xsl:value-of select="@TITLE"/> 
				</td>
				<td>
					<xsl:call-template name="CONTROL-ENV-WIDTH">
						<xsl:with-param name="inOneRow" select="$inOneRow"/>
						<xsl:with-param name="controlEnvStyle" select="$controlEnvStyle"/>
					</xsl:call-template>
					<xsl:call-template name="COMBO-BOX-CONTROL">
						<xsl:with-param name="controlClass"><xsl:value-of select="$controlClass"/></xsl:with-param>
						<xsl:with-param name="controlStyle"><xsl:value-of select="$controlStyle"/></xsl:with-param>
						<xsl:with-param name="onChange"><xsl:value-of select="$onChange"/></xsl:with-param>
					</xsl:call-template>
					<xsl:if test="$inOneRow = '' and @DESCRIPTION">
						<div class="{$descriptionClass}"><xsl:value-of select="@DESCRIPTION"/></div>
					</xsl:if>
				</td>
				<xsl:if test="$inOneRow and @DESCRIPTION">
					<td style="width: 40%;">
						<div class="{$descriptionClass}"><xsl:value-of select="@DESCRIPTION"/></div>
					</td>
				</xsl:if>
			</tr>
		</table>
	</xsl:template>

	<xsl:template match="CONTROL[@TYPE='COMBO-BOX']" name="COMBO-BOX-CONTROL">
		<xsl:param name="controlClass"></xsl:param>
		<xsl:param name="controlStyle"></xsl:param>
		<xsl:param name="onChange"></xsl:param>
		<xsl:param name="disabled"/>
		<select>
			<xsl:if test="$disabled = 1"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
			<xsl:if test="@DISABLED = 1"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
		
			<xsl:attribute name="name"><xsl:value-of select="@NAME"/></xsl:attribute>
			<xsl:if test="@ID">
				<xsl:attribute name="id"><xsl:value-of select="@ID"/></xsl:attribute>
			</xsl:if>			
			<xsl:if test="$controlClass!=''">
				<xsl:attribute name="class"><xsl:value-of select="$controlClass"/></xsl:attribute>
			</xsl:if>			
			<xsl:if test="$controlStyle!=''">
				<xsl:attribute name="style"><xsl:value-of select="$controlStyle"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="$onChange">
				<xsl:attribute name="onchange"><xsl:value-of select="$onChange"/></xsl:attribute>
			</xsl:if>
			
			<xsl:apply-templates match="CONTROL[@TYPE='COMBO-BOX-OPTION']"/>
		</select>
	</xsl:template>

	<xsl:template match="CONTROL[@TYPE='COMBO-BOX-OPTION']">		
		<option>
			<xsl:attribute name="value"><xsl:value-of select="@VALUE"/></xsl:attribute>
			<xsl:if test="@SELECTED">
				<xsl:attribute name="selected">selected</xsl:attribute>
			</xsl:if>
			<xsl:value-of select="@TITLE"/>
		</option>
	</xsl:template>

	<xsl:template match="CONTROL[@TYPE='INPUT' or @TYPE='PASSWORD']" name="TITLE-NONE" mode="TITLE-NONE">
		<xsl:param name="titleStyle"/>
		<xsl:param name="controlStyle"/>
		<xsl:param name="controlEnvStyle"/>
		<xsl:param name="titleClass"/>
		<xsl:param name="controlClass"/>
		<xsl:param name="title"/>
		<xsl:param name="value"/>
		<xsl:param name="name" value="@NAME"/>
		<xsl:param name="id" value="@NAME"/>
		<xsl:param name="require"/>
		<xsl:param name="type"/>
		<xsl:param name="disabled"/>
		<xsl:param name="rowClass"/>
		<xsl:param name="maxLength"/>
		<xsl:param name="autoComplete"/> 
		<xsl:param name="tabindex"/>
		<table cellpadding="0" cellspacing="0" border="0" style="width:100%">
			<tr>
				<xsl:attribute name="class"><xsl:value-of select="$rowClass"/></xsl:attribute>
				
				<td>
					<xsl:attribute name="style"><xsl:value-of select="$controlEnvStyle"/></xsl:attribute>
					<input maxlength="255" size="60">
						<xsl:if test="$maxLength">
							<xsl:attribute name="maxlength"><xsl:value-of select="$maxLength"/></xsl:attribute>
						</xsl:if>
								
						<xsl:if test="$tabindex">				
							<xsl:attribute name="tabindex"><xsl:value-of select="$tabindex"/></xsl:attribute>					  
						</xsl:if>
						<xsl:attribute name="autocomplete">
							<xsl:choose>
								<xsl:when test="$autoComplete"><xsl:value-of select="$autoComplete"/></xsl:when>
								<xsl:otherwise>off</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
										
						<xsl:attribute name="type">
							<xsl:choose>
								<xsl:when test="$type"><xsl:value-of select="$type"/></xsl:when>
								<xsl:otherwise>text</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
						<xsl:if test="$disabled = 1"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
						<xsl:attribute name="id"><xsl:value-of select="@NAME"/></xsl:attribute>
						<xsl:attribute name="id">
							<xsl:choose>
								<xsl:when test="$id"><xsl:value-of select="$id"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="@ID"/></xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>

						<xsl:attribute name="name">
							<xsl:choose>
								<xsl:when test="$name"><xsl:value-of select="$name"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="@NAME"/></xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:choose>
								<xsl:when test="$value"><xsl:value-of select="$value"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="@VALUE"/></xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
						<xsl:if test="$controlClass != ''">
							<xsl:attribute name="class"><xsl:value-of select="$controlClass"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="$controlStyle">
							<xsl:attribute name="style"><xsl:value-of select="$controlStyle"/></xsl:attribute>
						</xsl:if>
					</input>
					
					<xsl:if test="$require = 'on'">
						<span style="color:Red; width: 10px;">
							<xsl:attribute name="id"><xsl:value-of select="@ID"/>_asterix</xsl:attribute>
							<xsl:if test="$id">
								<xsl:attribute name="id"><xsl:value-of select="$id"/>_asterix</xsl:attribute>
							</xsl:if>
							&#160;*
						</span>
					</xsl:if>
				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template match="CONTROL[@TYPE='INPUT' or @TYPE='PASSWORD']" name="SIMPLE-INPUT">
		<xsl:param name="maxLength"/>
		<xsl:param name="tabindex"/>
		<xsl:param name="autoComplete"/> 
		<xsl:param name="type"/>
		<xsl:param name="disabled"/>
		<xsl:param name="value"/>
		<xsl:param name="name" value="@NAME"/>
		<xsl:param name="controlClass"/>
		<xsl:param name="controlStyle"/>
		<xsl:param name="require"/>
		<xsl:param name="id" value="@NAME"/>
		
		<input maxlength="255" size="60">
			<xsl:if test="$maxLength">
				<xsl:attribute name="maxlength"><xsl:value-of select="$maxLength"/></xsl:attribute>
			</xsl:if>
					
			<xsl:if test="$tabindex">				
				<xsl:attribute name="tabindex"><xsl:value-of select="$tabindex"/></xsl:attribute>					  
			</xsl:if>
			<xsl:attribute name="autocomplete">
				<xsl:choose>
					<xsl:when test="$autoComplete"><xsl:value-of select="$autoComplete"/></xsl:when>
					<xsl:otherwise>off</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
							
			<xsl:attribute name="type">
				<xsl:choose>
					<xsl:when test="$type"><xsl:value-of select="$type"/></xsl:when>
					<xsl:otherwise>text</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:if test="$disabled = 1"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
			<xsl:attribute name="id"><xsl:value-of select="@NAME"/></xsl:attribute>
			<xsl:attribute name="id">
				<xsl:choose>
					<xsl:when test="$id"><xsl:value-of select="$id"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="@ID"/></xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>

			<xsl:attribute name="name">
				<xsl:choose>
					<xsl:when test="$name"><xsl:value-of select="$name"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="@NAME"/></xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="value">
				<xsl:choose>
					<xsl:when test="$value"><xsl:value-of select="$value"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="@VALUE"/></xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
				<xsl:attribute name="class">
					sb-input 
					<xsl:if test="$controlClass != ''">
						<xsl:value-of select="$controlClass"/>
					</xsl:if>
				</xsl:attribute>
			<xsl:if test="$controlStyle">
				<xsl:attribute name="style"><xsl:value-of select="$controlStyle"/></xsl:attribute>
			</xsl:if>
		</input>
		
		<xsl:if test="$require = 'on'">
			<span style="color:Red; width: 10px;">
				<xsl:attribute name="id"><xsl:value-of select="@ID"/>_asterix</xsl:attribute>
				<xsl:if test="$id">
					<xsl:attribute name="id"><xsl:value-of select="$id"/>_asterix</xsl:attribute>
				</xsl:if>
				&#160;*
			</span>
		</xsl:if>
	</xsl:template>

	<xsl:template match="CONTROL[@TYPE='INPUT' or @TYPE='PASSWORD']" mode="TITLE-LEFT" name="INPUT-CONTROL">
		<xsl:param name="titleStyle"/>
		<xsl:param name="controlStyle"/>
		<xsl:param name="controlEnvStyle"/>
		<xsl:param name="titleClass"/>
		<xsl:param name="controlClass"/>
		<xsl:param name="descriptionClass">sb-text-pale</xsl:param>
		<xsl:param name="title"/>
		<xsl:param name="value" select="@VALUE"/>
		<xsl:param name="name"/>
		<xsl:param name="id"/>
		<xsl:param name="require" select="@REQUIRE"/>
		<xsl:param name="type" select="@TYPE"/>
		<xsl:param name="disabled" select="@DISABLED"/>
		<xsl:param name="rowClass"/>
		<xsl:param name="onChange"/>
		<xsl:param name="onClick"/>
		<xsl:param name="onBlur"/>
		<xsl:param name="maxLength"/>
		<xsl:param name="autoComplete"/>
		<xsl:param name="inOneRow"></xsl:param>
		<table cellpadding="0" cellspacing="0" border="0" style="width:100%; table-layout: fixed;">
			<tr style="vertical-align: baseline;">
				<xsl:attribute name="class"><xsl:value-of select="$rowClass"/></xsl:attribute>
				
				<td>
					<xsl:if test="$titleClass != ''">
						<xsl:attribute name="class"><xsl:value-of select="$titleClass"/></xsl:attribute>
					</xsl:if>
					<xsl:call-template name="CONTROL-WIDTH">
						<xsl:with-param name="inOneRow" select="$inOneRow"/>
						<xsl:with-param name="titleStyle" select="$titleStyle"/>
					</xsl:call-template>
					<xsl:choose>
						<xsl:when test="$title"><xsl:value-of select="$title"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="@TITLE"/></xsl:otherwise>
					</xsl:choose>
					<xsl:if test="$require = 'on'">
						<span><xsl:attribute name="style">color:Red; width: 10px;<xsl:if test="$value != ''">display:none;</xsl:if></xsl:attribute><xsl:attribute name="id"><xsl:choose>
							<xsl:when test="$id"><xsl:value-of select="$id"/></xsl:when>
							<xsl:when test="@ID"><xsl:value-of select="@ID"/></xsl:when>
							<xsl:when test="$name"><xsl:value-of select="$name"/></xsl:when>
							<xsl:otherwise><xsl:value-of select="@NAME"/></xsl:otherwise>
						</xsl:choose>_asterix</xsl:attribute>&#160;*</span>
					</xsl:if>
				</td>
				<td>
					<xsl:call-template name="CONTROL-ENV-WIDTH">
						<xsl:with-param name="inOneRow" select="$inOneRow"/>
						<xsl:with-param name="controlEnvStyle" select="$controlEnvStyle"/>
					</xsl:call-template>

					<input maxlength="255"  size="60" style="margin: 0px;">
						<xsl:if test="$maxLength">
							<xsl:attribute name="maxlength"><xsl:value-of select="$maxLength"/></xsl:attribute>
						</xsl:if>
                        
						<xsl:attribute name="autocomplete">
							<xsl:choose>
								<xsl:when test="$autoComplete"><xsl:value-of select="$autoComplete"/></xsl:when>
								<xsl:otherwise>off</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
								
						<xsl:attribute name="type">
							<xsl:choose>
								<xsl:when test="$type"><xsl:value-of select="$type"/></xsl:when>
								<xsl:otherwise>text</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
						<xsl:if test="$disabled = 1"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
						<xsl:attribute name="id">
							<xsl:choose>
								<xsl:when test="$id"><xsl:value-of select="$id"/></xsl:when>
								<xsl:when test="@ID"><xsl:value-of select="@ID"/></xsl:when>
								<xsl:when test="$name"><xsl:value-of select="$name"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="@NAME"/></xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
						
						<xsl:if test="$onChange">
							<xsl:attribute name="onchange"><xsl:value-of select="$onChange"/></xsl:attribute>
						</xsl:if>

						<xsl:if test="$onClick">
							<xsl:attribute name="onclick"><xsl:value-of select="$onClick"/></xsl:attribute>
						</xsl:if>

						<xsl:attribute name="onBlur">showAsterix(this.id);<xsl:value-of select="$onBlur"/></xsl:attribute>

						<xsl:attribute name="name">
							<xsl:choose>
								<xsl:when test="$name"><xsl:value-of select="$name"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="@NAME"/></xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:choose>
								<xsl:when test="$value"><xsl:value-of select="$value"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="@VALUE"/></xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
                        <xsl:if test="$controlClass != ''">
                            <xsl:attribute name="class"><xsl:value-of select="$controlClass"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="$controlStyle">
							<xsl:attribute name="style"><xsl:value-of select="$controlStyle"/></xsl:attribute>
						</xsl:if>
					</input>
					<xsl:if test="$inOneRow = '' and @DESCRIPTION">
						<div class="{$descriptionClass}"><xsl:value-of select="@DESCRIPTION"/></div>
					</xsl:if>
				</td>
				<xsl:if test="$inOneRow and @DESCRIPTION">
					<td style="width: 40%;">
						<div class="{$descriptionClass}"><xsl:value-of select="@DESCRIPTION"/></div>
					</td>
				</xsl:if>
			</tr>
		</table>
	</xsl:template>

	<xsl:template name="TEXTAREA-CONTROL">
		<xsl:param name="titleStyle"/>
		<xsl:param name="controlStyle"/>
		<xsl:param name="controlEnvStyle"/>
		<xsl:param name="titleClass"/>
		<xsl:param name="controlClass"/>
		<xsl:param name="title"/>
		<xsl:param name="value" select="@VALUE"/>
		<xsl:param name="name" select="@NAME"/>
		<xsl:param name="id" select="@ID"/>
		<xsl:param name="require"/>
		<xsl:param name="disabled"/>
		<xsl:param name="rowClass"/>
		<xsl:param name="onChange"/>
		<table cellpadding="0" cellspacing="0" border="0" style="width:100%; table-layout:fixed;">
			<tr class="{$rowClass}" style="vertical-align: baseline;">
				<td style="width:50%;" class="{$titleClass}">
					<xsl:attribute name="style">
						<xsl:value-of select="$titleStyle"/>
					</xsl:attribute>
					<xsl:choose>
						<xsl:when test="$title">
							<xsl:value-of select="$title"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="@TITLE"/>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:if test="$require = 'on'">
						<span style="color: red; width: 10px; vertical-align: top;">
							<xsl:attribute name="id">
								<xsl:value-of select="$id"/>
								<xsl:text>_asterix</xsl:text>
							</xsl:attribute>
							<xsl:text>&#160;*</xsl:text>
						</span>
					</xsl:if>
				</td>
				<td style="width:50%;">
					<xsl:if test="$controlEnvStyle">
						<xsl:attribute name="style"><xsl:value-of select="$controlEnvStyle"/></xsl:attribute>
					</xsl:if>
					<textarea>
						<xsl:if test="$disabled = 1">
							<xsl:attribute name="disabled">true</xsl:attribute>
						</xsl:if>
						<xsl:attribute name="id">
							<xsl:value-of select="$id"/>
						</xsl:attribute>
						<xsl:if test="$onChange">
							<xsl:attribute name="onchange">
								<xsl:value-of select="$onChange"/>
							</xsl:attribute>
						</xsl:if>
						<xsl:attribute name="name">
							<xsl:value-of select="$name"/>
						</xsl:attribute>
						<xsl:attribute name="class">
							<xsl:value-of select="$controlClass"/>
						</xsl:attribute>
						<xsl:attribute name="style">
							<xsl:value-of select="$controlStyle"/>
						</xsl:attribute>
						<xsl:value-of select="$value"/>
					</textarea>
				</td>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template match="CONTROL[@TYPE='INPUT']" mode="TITLE-TOP">
		<xsl:param name="titleStyle"></xsl:param>
		<xsl:param name="controlStyle"></xsl:param>
		<xsl:param name="titleClass"></xsl:param>
		<xsl:param name="controlClass"></xsl:param>
		<xsl:param name="require"/>
		<xsl:param name="onChange"/>
		<table cellpadding="0" cellspacing="0" border="0" style="width:100%; table-layout:fixed;">
			<tr>
				<td>
					<xsl:attribute name="class"><xsl:value-of select="$titleClass"/></xsl:attribute>
					<xsl:attribute name="style"><xsl:value-of select="$titleStyle"/></xsl:attribute>
					<xsl:value-of select="@TITLE"/> 
					<xsl:if test="$require = 'on'"><span style="color:Red; width: 10px;">&#160;*</span></xsl:if>					
				</td>
			</tr>
			<tr>
				<td>
					<input type="text" style="width:100%;{$controlStyle}">
						<xsl:attribute name="id"><xsl:value-of select="@ID"/></xsl:attribute>
						<xsl:attribute name="name"><xsl:value-of select="@NAME"/></xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="@VALUE"/></xsl:attribute>
						<xsl:attribute name="class"><xsl:value-of select="$controlClass"/></xsl:attribute>
						<xsl:attribute name="onChange"><xsl:value-of select="$onChange"/></xsl:attribute>
					</input>
				</td>
			</tr>
		</table>
	</xsl:template>
	
	
	<!-- ************************************************************************************************ -->	
	
<!-- -->
	<!--xsl:template match="CONTROL[@TYPE='TEXT']">
		<xsl:param name="textStyle"></xsl:param>
		<xsl:param name="colspan"></xsl:param>
		<tr>
			<td >
				<xsl:attribute name="class"><xsl:value-of select="$textStyle"/></xsl:attribute>
				<xsl:attribute name="colspan"><xsl:value-of select="$colspan"/></xsl:attribute>
				<xsl:value-of select="@VALUE"/> 
			</td>
		</tr>
	</xsl:template-->
<!-- -->
	
	<xsl:template match="CONTROL[@TYPE='TEXT']" mode="TITLE-LEFT" name="TEXT-CONTROL">
		<xsl:param name="titleStyle"/>
		<xsl:param name="controlStyle"/>
		<xsl:param name="controlEnvStyle"/>
		<xsl:param name="titleClass"/>
		<xsl:param name="controlClass"/>
		<xsl:param name="title"/>
		<xsl:param name="value"/>
		<xsl:param name="name"/>
		<xsl:param name="require"/>
		<xsl:param name="disabled"/>
		<xsl:param name="rowClass"/>
		<table cellpadding="0" cellspacing="0" border="0" style="width:100%; table-layout:fixed;">
			<tr style="vertical-align: baseline;">
				<xsl:attribute name="class"><xsl:value-of select="$rowClass"/></xsl:attribute>
				
				<td style="width:50%;">
					<xsl:if test="$titleClass">
						<xsl:attribute name="class"><xsl:value-of select="$titleClass"/></xsl:attribute>
					</xsl:if>
					<xsl:if test="$titleStyle">
						<xsl:attribute name="style"><xsl:value-of select="$titleStyle"/></xsl:attribute>	
					</xsl:if>
					<xsl:choose>
						<xsl:when test="$title"><xsl:value-of select="$title"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="@TITLE"/></xsl:otherwise>
					</xsl:choose>
				</td>
				<td>
					<xsl:attribute name="style"><xsl:value-of select="$controlEnvStyle"/></xsl:attribute>
					<span>
						<xsl:if test="$disabled = 1"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
						<xsl:attribute name="name">
							<xsl:choose>
								<xsl:when test="$name"><xsl:value-of select="$name"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="@NAME"/></xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
						<xsl:if test="$controlClass">
							<xsl:attribute name="class"><xsl:value-of select="$controlClass"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="$controlStyle">
							<xsl:attribute name="style"><xsl:value-of select="$controlStyle"/></xsl:attribute>
						</xsl:if>
						<xsl:call-template name="nl2br">
							<xsl:with-param name="string" select="@VALUE"/>
						</xsl:call-template>
					</span>
				</td>
				<xsl:if test="$require = 'on'">
				<td style="color:Red; width: 10px;">&#160;*</td>
				</xsl:if>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template match="CONTROL[@TYPE='TEXT']" mode="TITLE-TOP">
		<xsl:param name="titleStyle"></xsl:param>
		<xsl:param name="controlStyle"></xsl:param>
		<xsl:param name="titleClass"></xsl:param>
		<xsl:param name="controlClass"></xsl:param>
		<table width="100%" cellpadding="0" cellspacing="0" border="0">
			<tr>
				<td>
					<xsl:if test="$titleClass">
						<xsl:attribute name="class"><xsl:value-of select="$titleClass"/></xsl:attribute>
					</xsl:if>
					<xsl:if test="$titleStyle">
						<xsl:attribute name="style"><xsl:value-of select="$titleStyle"/></xsl:attribute>	
					</xsl:if>
					<xsl:value-of select="@TITLE"/> 
				</td>
			</tr>
			<tr>
				<td style="width:100%">
					<span>
						<xsl:attribute name="name"><xsl:value-of select="@NAME"/></xsl:attribute>
						<xsl:if test="$controlClass">
							<xsl:attribute name="class"><xsl:value-of select="$controlClass"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="$controlStyle">
							<xsl:attribute name="style"><xsl:value-of select="$controlStyle"/></xsl:attribute>
						</xsl:if>
						<xsl:value-of select="@VALUE"/>
					</span>
				</td>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template match="CONTROL[@TYPE='LABEL']" name="LABEL-CONTROL">
		<xsl:param name="titleStyle"></xsl:param>
		<xsl:param name="controlStyle"></xsl:param>
		<xsl:call-template name="TITLE-TOP"/>
		<tr>
			<xsl:call-template name="TITLE-LEFT">
				<xsl:with-param name="titleStyle"><xsl:value-of select="$titleStyle"/></xsl:with-param>
			</xsl:call-template>
			<td>
				<div>
					<xsl:attribute name="class"><xsl:value-of select="$controlStyle"/></xsl:attribute>
					<xsl:value-of select="@VALUE"/> 
				</div>
			</td>
			<xsl:call-template name="TITLE-RIGHT">
				<xsl:with-param name="titleStyle"><xsl:value-of select="$titleStyle"/></xsl:with-param>
			</xsl:call-template>
		</tr>
		<xsl:call-template name="TITLE-BOTTOM">
			<xsl:with-param name="titleStyle"><xsl:value-of select="$titleStyle"/></xsl:with-param>
		</xsl:call-template>
	</xsl:template>

<!--	<xsl:template name="TEXT-CONTROL">
		<xsl:value-of select="@VALUE"/> 
	</xsl:template>
-->	
	
	
	<xsl:template match="CONTROL[@TYPE='PASSWORD']">
		<xsl:param name="titleStyle"></xsl:param>
		<xsl:param name="controlStyle"></xsl:param>
		<xsl:call-template name="TITLE-TOP"/>
		<tr>
			<xsl:call-template name="TITLE-LEFT">
				<xsl:with-param name="titleStyle"><xsl:value-of select="$titleStyle"/></xsl:with-param>
			</xsl:call-template>
			<td>
				<input type="password">
					<xsl:attribute name="name"><xsl:value-of select="@NAME"/></xsl:attribute>
					<xsl:attribute name="id"><xsl:value-of select="@NAME"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="@VALUE"/></xsl:attribute>
					<xsl:attribute name="class"><xsl:value-of select="$controlStyle"/></xsl:attribute>
				</input>
			</td>
			<xsl:call-template name="TITLE-RIGHT">
				<xsl:with-param name="titleStyle"><xsl:value-of select="$titleStyle"/></xsl:with-param>
			</xsl:call-template>
		</tr>
		<xsl:call-template name="TITLE-BOTTOM">
			<xsl:with-param name="titleStyle"><xsl:value-of select="$titleStyle"/></xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="CONTROL[@TYPE='CHECKBOX']">
		<xsl:param name="textStyle"></xsl:param>
		<xsl:param name="colspan"></xsl:param>
		<xsl:param name="controlStyle"></xsl:param>
		<td>
			<xsl:attribute name="class"><xsl:value-of select="$textStyle"/></xsl:attribute>
			<xsl:attribute name="colspan"><xsl:value-of select="$colspan"/></xsl:attribute>
        	<input type="checkbox">
				<xsl:if test="@CHECKED">
					<xsl:attribute name="checked">true</xsl:attribute>
				</xsl:if>
				<xsl:attribute name="name"><xsl:value-of select="@NAME"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="@VALUE"/></xsl:attribute>
				<xsl:attribute name="class"><xsl:value-of select="$controlStyle"/></xsl:attribute>
			</input>
			<xsl:value-of select="@TITLE-RIGHT"/>
        </td>	
    </xsl:template>

	<xsl:template match="CONTROL[@TYPE='CHECKBOX']" name="CHECKBOX-CONTROL" mode="TITLE-RIGHT">
		<xsl:param name="titleStyle"/>
		<xsl:param name="controlStyle"/>
		<xsl:param name="titleClass"/>
		<xsl:param name="controlClass"/>
		<xsl:param name="title"/>
		<xsl:param name="name"/>
		<xsl:param name="value"/>
		<xsl:param name="id"/>
		<xsl:param name="type" select="@TYPE"/>
		<xsl:param name="disabled" select="@DISABLED"/>
		<xsl:param name="onChange"/>
		<xsl:param name="onClick"/>
		<xsl:param name="onBlur"/>
		<xsl:param name="checked" select="@CHECKED"/>
		<table cellpadding="0" cellspacing="0" border="0">
			<tr>
				<td style="padding-right: 7px;">
					<input type="checkbox" style="margin: 0;">
						<xsl:if test="$checked>0">
							<xsl:attribute name="checked">true</xsl:attribute>
						</xsl:if>
						<xsl:if test="$disabled = 1"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
						<xsl:attribute name="id">
							<xsl:choose>
								<xsl:when test="$id"><xsl:value-of select="$id"/></xsl:when>
								<xsl:when test="@ID"><xsl:value-of select="@ID"/></xsl:when>
								<xsl:when test="$name"><xsl:value-of select="$name"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="@NAME"/></xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>

						<xsl:if test="$onChange">
							<xsl:attribute name="onchange"><xsl:value-of select="$onChange"/></xsl:attribute>
						</xsl:if>

						<xsl:if test="$onClick">
							<xsl:attribute name="onclick"><xsl:value-of select="$onClick"/></xsl:attribute>
						</xsl:if>

						<xsl:attribute name="onBlur">showAsterix(this.id);<xsl:value-of select="$onBlur"/></xsl:attribute>

						<xsl:attribute name="name">
							<xsl:choose>
								<xsl:when test="$name"><xsl:value-of select="$name"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="@NAME"/></xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
						
						<xsl:attribute name="value">
							<xsl:choose>
								<xsl:when test="$value"><xsl:value-of select="$value"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="@VALUE"/></xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
						
						<xsl:if test="$controlStyle">
							<xsl:attribute name="style"><xsl:value-of select="$controlStyle"/></xsl:attribute>
						</xsl:if>
					</input>
				</td>
				<td>
					<xsl:if test="$titleClass != ''">
						<xsl:attribute name="class"><xsl:value-of select="$titleClass"/></xsl:attribute>
					</xsl:if>
							<label style="width: 100%;">
								<xsl:attribute name="for">
									<xsl:choose>
										<xsl:when test="$id"><xsl:value-of select="$id"/></xsl:when>
										<xsl:when test="@ID"><xsl:value-of select="@ID"/></xsl:when>
										<xsl:when test="$name"><xsl:value-of select="$name"/></xsl:when>
										<xsl:otherwise><xsl:value-of select="@NAME"/></xsl:otherwise>
									</xsl:choose>
								</xsl:attribute>
								<xsl:choose>
									<xsl:when test="$title"><xsl:value-of select="$title"/></xsl:when>
									<xsl:otherwise><xsl:value-of select="@TITLE"/></xsl:otherwise>
								</xsl:choose>
							</label>
				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template match="CONTROL[@TYPE='CHECKBOX']" mode="TITLE-LEFT">
		<xsl:param name="titleStyle"/>
		<xsl:param name="controlStyle"/>
		<xsl:param name="titleClass"/>
		<xsl:param name="controlClass"/>
		<xsl:param name="title"/>
		<xsl:param name="name"/>
		<xsl:param name="value"/>
		<xsl:param name="id"/>
		<xsl:param name="type" select="@TYPE"/>
		<xsl:param name="disabled" select="@DISABLED"/>
		<xsl:param name="onChange"/>
		<xsl:param name="onClick"/>
		<xsl:param name="onBlur"/>
		<xsl:param name="checked" select="@CHECKED"/>
		<table cellpadding="0" cellspacing="0" border="0" width="100%">
			<tr>
				<td width="50%">
					<xsl:if test="$titleClass != ''">
						<xsl:attribute name="class"><xsl:value-of select="$titleClass"/></xsl:attribute>
					</xsl:if>
							<label style="width: 100%;">
								<xsl:attribute name="for">
									<xsl:choose>
										<xsl:when test="$id"><xsl:value-of select="$id"/></xsl:when>
										<xsl:when test="@ID"><xsl:value-of select="@ID"/></xsl:when>
										<xsl:when test="$name"><xsl:value-of select="$name"/></xsl:when>
										<xsl:otherwise><xsl:value-of select="@NAME"/></xsl:otherwise>
									</xsl:choose>
								</xsl:attribute>
								<xsl:choose>
									<xsl:when test="$title"><xsl:value-of select="$title"/></xsl:when>
									<xsl:otherwise><xsl:value-of select="@TITLE"/></xsl:otherwise>
								</xsl:choose>
							</label>
				</td>
				<td width="50%">
					<input type="checkbox" style="margin: 0;">
						<xsl:if test="$checked>0">
							<xsl:attribute name="checked">true</xsl:attribute>
						</xsl:if>
						<xsl:if test="$disabled = 1"><xsl:attribute name="disabled">true</xsl:attribute></xsl:if>
						<xsl:attribute name="id">
							<xsl:choose>
								<xsl:when test="$id"><xsl:value-of select="$id"/></xsl:when>
								<xsl:when test="@ID"><xsl:value-of select="@ID"/></xsl:when>
								<xsl:when test="$name"><xsl:value-of select="$name"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="@NAME"/></xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>

						<xsl:if test="$onChange">
							<xsl:attribute name="onchange"><xsl:value-of select="$onChange"/></xsl:attribute>
						</xsl:if>

						<xsl:if test="$onClick">
							<xsl:attribute name="onclick"><xsl:value-of select="$onClick"/></xsl:attribute>
						</xsl:if>

						<xsl:attribute name="onBlur">showAsterix(this.id);<xsl:value-of select="$onBlur"/></xsl:attribute>

						<xsl:attribute name="name">
							<xsl:choose>
								<xsl:when test="$name"><xsl:value-of select="$name"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="@NAME"/></xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
						
						<xsl:attribute name="value">
							<xsl:choose>
								<xsl:when test="$value"><xsl:value-of select="$value"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="@VALUE"/></xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
						
						<xsl:if test="$controlStyle">
							<xsl:attribute name="style"><xsl:value-of select="$controlStyle"/></xsl:attribute>
						</xsl:if>
					</input>
				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template match="CONTROL[@TYPE='LINK']">
		<xsl:param name="style"></xsl:param>
		<a href="#">
			<xsl:attribute name="class"><xsl:value-of select="$style"/></xsl:attribute>
			<xsl:attribute name="href"><xsl:value-of select="@HREF"/></xsl:attribute>
			<xsl:value-of select="@TITLE"/>
		</a>    		
    </xsl:template>

	<xsl:template name="TITLE-TOP">
		<xsl:param name="titleStyle"></xsl:param>
		<xsl:if test="@TITLE-TOP">
			<tr>
				<td>
					<xsl:attribute name="class"><xsl:value-of select="$titleStyle"/></xsl:attribute>				
					<xsl:value-of select="@TITLE-TOP"/> 
				</td>
			</tr>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="TITLE-LEFT">
		<xsl:param name="titleStyle"></xsl:param>
		<xsl:if test="@TITLE-LEFT">
			<td>
				<xsl:attribute name="class"><xsl:value-of select="$titleStyle"/></xsl:attribute>				
				<xsl:value-of select="@TITLE-LEFT"/> 
			</td>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="TITLE-RIGHT">
		<xsl:param name="titleStyle"></xsl:param>
		<xsl:if test="@TITLE-RIGHT">
			<td>
				<xsl:attribute name="class"><xsl:value-of select="$titleStyle"/></xsl:attribute>				
				<xsl:value-of select="@TITLE-RIGHT"/> 
			</td>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="TITLE-BOTTOM">
		<xsl:param name="titleStyle"></xsl:param>
		<xsl:if test="@TITLE-BOTTOM">
			<tr>
				<td>
					<xsl:attribute name="class"><xsl:value-of select="$titleStyle"/></xsl:attribute>				
					<xsl:value-of select="@TITLE-BOTTOM"/> 
				</td>
			</tr>
		</xsl:if>
	</xsl:template>

	<xsl:template match="CONTROL[@TYPE='INPUT']">
		<xsl:value-of select="@VALUE"/>
	</xsl:template>
	
	<xsl:template match="CONTROL[@TYPE='GAUGE']" name="GAUGE-CONTROL">
		<table cellspacing="0" cellpadding="0" border="0" style="width:100%;">
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="@CURRENT > 0">
							<xsl:attribute name="class">sb-statbar-left-filled</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">sb-statbar-left</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<img src="/images/blank.gif" width="3" height="9"/>
				</td>
				<td class="sb-statbar-middle" width="100%">
					<xsl:choose>
						<xsl:when test="@CURRENT > 0">
							<img src="{$skinPath}/images/statline_abg.gif" height="9" width="0">
								<xsl:if test="@CURRENT > @TOTAL">
									<xsl:attribute name="width">100%</xsl:attribute>
								</xsl:if>
								<xsl:if test="@CURRENT > 0">
									<xsl:if test="@TOTAL > 0">
										<xsl:attribute name="width"><xsl:value-of select="(@CURRENT*100) div @TOTAL"/>%</xsl:attribute>
									</xsl:if>
								</xsl:if>
							</img>
						</xsl:when>
						<xsl:otherwise>
							<img src="/images/blank.gif" width="1" height="9"/>
						</xsl:otherwise>
					</xsl:choose>					
				</td>
				<td class="sb-statbar-right">
					<xsl:choose>
						<xsl:when test="@CURRENT >= @TOTAL">
							<xsl:attribute name="class">sb-statbar-right-filled</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">sb-statbar-right</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<img src="/images/blank.gif" width="3" height="9"/>
				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template name="REQUIRED-FIELDS">
		<div style="white-space:nowrap; padding-left: 8px;">
			<span class="sb-asterix">*</span>&#160;<span class="sb-text-pale"><xsl:value-of select="/SITEBUILDER-PAGE/LOCALE/REQUIRED-FIELDS"/></span>
		</div>
	</xsl:template>
	
</xsl:stylesheet>
